==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/lt_LT.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Storage invalid" : "Saugykla netinkama naudoti",
    "Unknown error" : "Nežinoma klaida",
    "All files" : "Visi failai",
    "Recent" : "Naujausi",
    "File could not be found" : "Nepavyko rasti rinkmenos",
    "Download" : "Atsisiųsti",
    "Delete" : "Ištrinti",
    "Home" : "Pagrindinis",
    "Close" : "Užverti",
    "Could not create folder \"{dir}\"" : "Nepavyko sukurti aplanko \"{dir}\"",
    "Upload cancelled." : "Įkėlimo atsisakyta.",
    "…" : "...",
    "Processing files …" : "Apdorojami failai …",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nepavyksta įkelti {filename}, nes tai yra katalogas arba šio failo dydis yra 0 baitų",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nepakanka laisvos vietos. Jūs bandote įkelti {size1} dydžio bylą, bet liko tik  {size2} vietos",
    "Target folder \"{dir}\" does not exist any more" : "Paskirties aplanko \"{dir}\" daugiau nebėra",
    "Not enough free space" : "Trūksta laisvos vietos",
    "Uploading …" : "Įkeliama …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} iš {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "To elemento įkėlimas nėra palaikomas",
    "Target folder does not exist any more" : "Paskirties aplanko daugiau nebėra",
    "Actions" : "Veiksmai",
    "Rename" : "Pervadinti",
    "Copy" : "Kopijuoti",
    "Disconnect storage" : "Atjungti saugyklą",
    "Could not load info for file \"{file}\"" : "Nepavyko įkelti informacijos failui \"{file}\"",
    "Files" : "Failai",
    "Details" : "Informacija",
    "Select" : "Pasirinkti",
    "Unable to determine date" : "Nepavyksta nustatyti datos",
    "This operation is forbidden" : "Ši operacija yra uždrausta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Katalogas neprieinamas, prašome peržiūrėti žurnalo įrašus arba susisiekti su administratoriumi",
    "Could not move \"{file}\", target exists" : "Nepavyko perkelti \"{file}\", toks jau egzistuoja",
    "Could not move \"{file}\"" : "Nepavyko perkelti \"{file}\"",
    "Could not copy \"{file}\"" : "Nepavyko nukopijuoti \"{file}\"",
    "{newName} already exists" : "{newName} jau yra",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nepavyko pervadinti bylos \"{fileName}\", nes tokia byla neegzistuoja",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Pavadinimas \"{targetName}\" jau naudojamas aplanke \"{dir}\". Prašome pasirinkti kitokį pavadinimą.",
    "Could not rename \"{fileName}\"" : "Nepavyko pervadinti failo \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nepavyko sukurti failo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nepavyko sukurti failo \"{file}\" - failas su tokiu pavadinimu jau egzistuoja",
    "Could not create folder \"{dir}\" because it already exists" : "Nepavyko sukurti aplanko \"{dir}\"- aplankas su tokiu pavadinimu jau egzistuoja",
    "Error deleting file \"{fileName}\"." : "Klaida trinant failą \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Kituose aplankuose nėra paieškos rezultatų, skirtų {tag}{filter}{endtag}",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankų"],
    "_%n file_::_%n files_" : ["%n failas","%n failai","%n failų","%n failų"],
    "{dirs} and {files}" : "{dirs} ir {files}",
    "_including %n hidden_::_including %n hidden_" : ["įskaitant %n paslėptą","įskaitant %n paslėptus","įskaitant %n paslėptų","įskaitant %n paslėptų"],
    "You don’t have permission to upload or create files here" : "Jūs neturite leidimo čia įkelti arba kurti failus",
    "_Uploading %n file_::_Uploading %n files_" : ["Įkeliamas %n failas","Įkeliami %n failai","Įkeliama %n failų","Įkeliama %n failų"],
    "New" : "Naujas",
    "{used} of {quota} used" : "panaudota {used} iš {quota}",
    "\"{name}\" is an invalid file name." : "„{name}“ yra netinkamas bylos pavadinimas.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nėra leidžiamas failo tipas",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} saugykla yra pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsų saugykla pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} saugykla yra beveik pilna ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsų saugykla yra beveik pilna ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atitinka '{filter}'","atitinka '{filter}'","atitinka '{filter}'","atitinka '{filter}'"],
    "View in folder" : "Rodyti aplanke",
    "Copied!" : "Nukopijuota!",
    "Path" : "Kelias",
    "_%n byte_::_%n bytes_" : ["%n baitas","%n baitai","%n baitų","%n baitų"],
    "Favorited" : "Svarbus",
    "Favorite" : "Svarbus",
    "New folder" : "Naujas aplankas",
    "Upload file" : "Įkelti failą",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "An error occurred while trying to update the tags" : "Bandant atnaujinti žymes įvyko klaida",
    "Added to favorites" : "Pridėta prie mėgstamųjų",
    "Removed from favorites" : "Pašalinta iš mėgstamųjų",
    "You added {file} to your favorites" : "Jūs pridėjote {file} prie mėgstamųjų",
    "You removed {file} from your favorites" : "Jūs pašalinote {file} iš mėgstamųjų",
    "File changes" : "Failo pakeitimai",
    "Created by {user}" : "Sukūrė {user}",
    "Changed by {user}" : "Pakeitė {user}",
    "Deleted by {user}" : "Ištrynė {user}",
    "Restored by {user}" : "Atkūrė {user}",
    "Renamed by {user}" : "Pervadino {user}",
    "Moved by {user}" : "Perkėlė {user}",
    "\"remote user\"" : "\"nuotolinis naudotojas\"",
    "You created {file}" : "Jūs sukūrėte {file}",
    "{user} created {file}" : "{user} sukūrė {file}",
    "{file} was created in a public folder" : "{file} buvo sukurtas viešajame aplanke",
    "You changed {file}" : "Jūs pakeitėte {file}",
    "{user} changed {file}" : "{user} pakeitė {file}",
    "You deleted {file}" : "Jūs ištrynėte {file}",
    "{user} deleted {file}" : "{user} ištrynė {file}",
    "You restored {file}" : "{file} atkurtas",
    "{user} restored {file}" : "{user} atkūrė {file}",
    "You renamed {oldfile} to {newfile}" : " {oldfile} pervadintas į {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} pervadino {oldfile} į {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} perkeltas į {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} perkėlė {oldfile} į {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Failas buvo pridėtas arba pašalintas iš <strong>mėgstamųjų</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Buvo <strong>pakeistas</strong> ar <strong>pervadintas</strong> failas ar aplankas",
    "A new file or folder has been <strong>created</strong>" : "Buvo <strong>sukurtas</strong> naujas failas ar aplankas",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Riboti pranešimus apie sukūrimą ir pokyčius jūsų <strong>mėgiamuose failuose</strong> <em>(Tik srautas)</em>",
    "Unlimited" : "Neribotai",
    "Upload (max. %s)" : "Įkelti (maks. %s)",
    "File Management" : "Failų tvarkymas",
    "File handling" : "Failų tvarkymas",
    "Maximum upload size" : "Maksimalus įkeliamo failo dydis",
    "max. possible: " : "maks. galima:",
    "Save" : "Įrašyti",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Su PHP-FPM atnaujinimai gali užtrukti apie 5min.",
    "Missing permissions to edit from here." : "Draudžiama iš čia redaguoti",
    "%s of %s used" : "naudojama %s iš %s",
    "%s used" : "%s panaudota",
    "Settings" : "Nustatymai",
    "Show hidden files" : "Rodyti paslėptus failus",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Atsisakyti įkėlimo",
    "No files in here" : "Čia failų nėra",
    "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
    "Select all" : "Pažymėti viską",
    "Upload too large" : "Įkėlimui failas per didelis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Bandomų įkelti failų dydis viršija maksimalų, šiame serveryje leidžiamų įkelti failų dydį.",
    "Tags" : "Žymės",
    "Deleted files" : "Ištrinti failai",
    "Shares" : "Viešiniai",
    "Deleted shares" : "Ištrinti viešiniai",
    "Text file" : "Tekstinis failas",
    "New text file.txt" : "Naujas tekstinis failas.txt",
    "Target folder" : "Paskirties aplankas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-15.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/lt_LT.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Storage invalid" : "Saugykla netinkama naudoti",
    "Unknown error" : "Nežinoma klaida",
    "All files" : "Visi failai",
    "Recent" : "Naujausi",
    "Favorites" : "Svarbiausi",
    "File could not be found" : "Nepavyko rasti failo",
    "Move or copy" : "Perkelti ar kopijuoti",
    "Download" : "Atsisiųsti",
    "Delete" : "Ištrinti",
    "Home" : "Pagrindinis",
    "Close" : "Užverti",
    "Could not create folder \"{dir}\"" : "Nepavyko sukurti aplanko \"{dir}\"",
    "Upload cancelled." : "Įkėlimas atšauktas.",
    "Processing files …" : "Apdorojami failai …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nepavyksta įkelti {filename}, nes tai yra katalogas arba šio failo dydis yra 0 baitų",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nepakanka laisvos vietos. Jūs bandote įkelti {size1} dydžio bylą, bet liko tik  {size2} vietos",
    "Target folder \"{dir}\" does not exist any more" : "Paskirties aplanko \"{dir}\" daugiau nebėra",
    "Not enough free space" : "Trūksta laisvos vietos",
    "An unknown error has occurred" : "Įvyko nežinoma klaida",
    "Uploading …" : "Įkeliama …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} iš {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "To elemento įkėlimas nėra palaikomas",
    "Target folder does not exist any more" : "Paskirties aplanko daugiau nebėra",
    "Actions" : "Veiksmai",
    "Rename" : "Pervadinti",
    "Copy" : "Kopijuoti",
    "Disconnect storage" : "Atjungti saugyklą",
    "Unshare" : "Nebesidalinti",
    "Could not load info for file \"{file}\"" : "Nepavyko įkelti informacijos failui \"{file}\"",
    "Files" : "Failai",
    "Details" : "Duomenys",
    "Select" : "Pasirinkti",
    "Pending" : "Laukiantis",
    "Unable to determine date" : "Nepavyksta nustatyti datos",
    "This operation is forbidden" : "Ši operacija yra uždrausta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis katalogas neprieinamas, prašome peržiūrėti žurnalo įrašus arba susisiekti su administratoriumi",
    "Could not move \"{file}\", target exists" : "Nepavyko perkelti \"{file}\", toks jau egzistuoja",
    "Could not move \"{file}\"" : "Nepavyko perkelti \"{file}\"",
    "copy" : "kopija",
    "Could not copy \"{file}\", target exists" : "Nepavyko nukopijuoti \"{file}\", toks jau yra",
    "Could not copy \"{file}\"" : "Nepavyko nukopijuoti \"{file}\"",
    "{newName} already exists" : "{newName} jau yra",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nepavyko pervadinti bylos \"{fileName}\", nes tokia byla neegzistuoja",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Pavadinimas \"{targetName}\" jau naudojamas aplanke \"{dir}\". Prašome pasirinkti kitokį pavadinimą.",
    "Could not rename \"{fileName}\"" : "Nepavyko pervadinti failo \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nepavyko sukurti failo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nepavyko sukurti failo \"{file}\" - failas su tokiu pavadinimu jau egzistuoja",
    "Could not create folder \"{dir}\" because it already exists" : "Nepavyko sukurti aplanko \"{dir}\"- aplankas su tokiu pavadinimu jau egzistuoja",
    "Error deleting file \"{fileName}\"." : "Klaida trinant failą \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Kituose aplankuose nėra paieškos rezultatų, skirtų {tag}{filter}{endtag}",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeistas",
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankų"],
    "_%n file_::_%n files_" : ["%n failas","%n failai","%n failų","%n failų"],
    "{dirs} and {files}" : "{dirs} ir {files}",
    "_including %n hidden_::_including %n hidden_" : ["įskaitant %n paslėptą","įskaitant %n paslėptus","įskaitant %n paslėptų","įskaitant %n paslėptų"],
    "You don’t have permission to upload or create files here" : "Jūs neturite leidimo čia įkelti arba kurti failus",
    "_Uploading %n file_::_Uploading %n files_" : ["Įkeliamas %n failas","Įkeliami %n failai","Įkeliama %n failų","Įkeliama %n failų"],
    "New" : "Naujas",
    "{used} of {quota} used" : "panaudota {used} iš {quota}",
    "\"{name}\" is an invalid file name." : "„{name}“ yra netinkamas bylos pavadinimas.",
    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nėra leidžiamas failo tipas",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} saugykla yra pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsų saugykla pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} saugykla yra beveik pilna ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsų saugykla yra beveik pilna ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atitinka '{filter}'","atitinka '{filter}'","atitinka '{filter}'","atitinka '{filter}'"],
    "View in folder" : "Rodyti aplanke",
    "Copied!" : "Nukopijuota!",
    "Path" : "Kelias",
    "_%n byte_::_%n bytes_" : ["%n baitas","%n baitai","%n baitų","%n baitų"],
    "Favorited" : "Svarbiausias",
    "Favorite" : "Svarbiausias",
    "You can only favorite a single file or folder at a time" : "Vienu metu svarbiu pažymėti galite tik vieną failą ar aplanką",
    "New folder" : "Naujas aplankas",
    "Upload file" : "Įkelti failą",
    "Not favorited" : "Nepažymėtas svarbiu",
    "Remove from favorites" : "Šalinti iš svarbiausių",
    "Add to favorites" : "Pridėti prie svarbiausių",
    "An error occurred while trying to update the tags" : "Bandant atnaujinti žymes įvyko klaida",
    "Added to favorites" : "Pridėta prie mėgstamųjų",
    "Removed from favorites" : "Pašalintas iš svarbiausių",
    "You added {file} to your favorites" : "Pridėjote {file} prie svarbiausių",
    "You removed {file} from your favorites" : "Pašalinote {file} iš svarbiausių",
    "File changes" : "Failo pakeitimai",
    "Created by {user}" : "Sukūrė {user}",
    "Changed by {user}" : "Pakeitė {user}",
    "Deleted by {user}" : "Ištrynė {user}",
    "Restored by {user}" : "Atkūrė {user}",
    "Renamed by {user}" : "Pervadino {user}",
    "Moved by {user}" : "Perkėlė {user}",
    "\"remote user\"" : "\"nuotolinis naudotojas\"",
    "You created {file}" : "Jūs sukūrėte {file}",
    "{user} created {file}" : "{user} sukūrė {file}",
    "{file} was created in a public folder" : "{file} buvo sukurtas viešajame aplanke",
    "You changed {file}" : "Jūs pakeitėte {file}",
    "{user} changed {file}" : "{user} pakeitė {file}",
    "You deleted {file}" : "Jūs ištrynėte {file}",
    "{user} deleted {file}" : "{user} ištrynė {file}",
    "You restored {file}" : "{file} atkurtas",
    "{user} restored {file}" : "{user} atkūrė {file}",
    "You renamed {oldfile} to {newfile}" : " {oldfile} pervadintas į {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} pervadino {oldfile} į {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} perkeltas į {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} perkėlė {oldfile} į {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Failas buvo pridėtas arba pašalintas iš <strong>svarbiausių</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Buvo <strong>pakeistas</strong> ar <strong>pervadintas</strong> failas ar aplankas",
    "A new file or folder has been <strong>created</strong>" : "Buvo <strong>sukurtas</strong> naujas failas ar aplankas",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Riboti pranešimus apie sukūrimą ir pokyčius jūsų <strong>svarbiausuose failuose</strong> <em>(Tik srautas)</em>",
    "A file or folder has been <strong>restored</strong>" : "Failas ar aplankas <strong>atkurtas</strong>",
    "Unlimited" : "Neribotai",
    "Upload (max. %s)" : "Įkelti (maks. %s)",
    "File Management" : "Failų tvarkymas",
    "%s of %s used" : "naudojama %s iš %s",
    "%s used" : "%s panaudota",
    "Settings" : "Nustatymai",
    "Show hidden files" : "Rodyti paslėptus failus",
    "WebDAV" : "WebDAV",
    "No files in here" : "Čia failų nėra",
    "Upload some content or sync with your devices!" : "Įkelkite failų arba sinchronizuokite su savo įrenginiais!",
    "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
    "Select all" : "Pažymėti viską",
    "Upload too large" : "Įkėlimui failas per didelis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Bandomų įkelti failų dydis viršija maksimalų, šiame serveryje leidžiamų įkelti failų dydį.",
    "No favorites yet" : "Svarbiausių dar nėra",
    "Files and folders you mark as favorite will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos pažymėsite kaip svarbiausius",
    "Tags" : "Žymės",
    "Deleted files" : "Ištrinti failai",
    "Shares" : "Viešiniai",
    "Deleted shares" : "Ištrinti viešiniai",
    "Text file" : "Tekstinis failas",
    "New text file.txt" : "Naujas tekstinis failas.txt",
    "Target folder" : "Paskirties aplankas",
    "File handling" : "Failų apdorojimas",
    "Maximum upload size" : "Maksimalus įkeliamo failo dydis",
    "max. possible: " : "daug. leidžiama:",
    "Save" : "Įrašyti",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Naudojant PHP-FPM, pakeitimų taikymas gali užtrukti 5 minutes.",
    "Missing permissions to edit from here." : "Draudžiama iš čia redaguoti",
    "Cancel upload" : "Atsisakyti įkėlimo"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
